@@ -312,7 +312,7 @@ class ReplaceTokensWithFile extends BaseParamFilterReader implements ChainableRe
 
         // filter buffer
         $buffer = preg_replace_callback(
-            "/" . preg_quote($this->_beginToken) . "([\w\.\-:\/]+?)" . preg_quote($this->_endToken) . "/",
+            "$" . preg_quote($this->_beginToken) . "([\w\.\-:\/]+?)" . preg_quote($this->_endToken) . "$",
             array($this, 'replaceTokenCallback'),
             $buffer
         );
