@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: 88d960e37146f978be47dfb583cef5cd80f55c1d $
+ * $Id: 130043b9c5265eac0037f234cad0c2cbe5a73c11 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -28,7 +28,7 @@ include_once 'phing/system/util/Properties.php';
  *
  * @author     Michiel Rook <mrook@php.net>
  * @package    phing.listener
- * @version    $Id: 88d960e37146f978be47dfb583cef5cd80f55c1d $
+ * @version    $Id: 130043b9c5265eac0037f234cad0c2cbe5a73c11 $
  */
 class MailLogger extends DefaultLogger
 {
@@ -97,7 +97,7 @@ class MailLogger extends DefaultLogger
 
         $hdrs = array(
             'From' => $this->_from,
-            'Subject' => $this->_subject . (empty($event) ? " (build succesful)" : " (build failed)")
+            'Subject' => $this->_subject . (empty($event) ? " (build successful)" : " (build failed)")
         );
 
         $mail = Mail::factory('mail');
