@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: f3fdc5c0e9bb25121b04d1d17d6e5ddb2d091593 $
+ *  $Id: 553b6c3f96f78c68a753a8c9b0483f197df21bfd $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -231,6 +231,8 @@ class Win32FileSystem extends FileSystem
      */
     public function normalize($strPath)
     {
+        $strPath = $this->fixEncoding($strPath);
+
         if ($this->_isPharArchive($strPath)) {
             return str_replace('\\', '/', $strPath);
         }
@@ -620,4 +622,21 @@ class Win32FileSystem extends FileSystem
         return $vv;
     }
 
+    /**
+     * On Windows platforms, PHP will mangle non-ASCII characters, see http://bugs.php.net/bug.php?id=47096
+     *
+     * @param $strPath
+     * @return mixed|string
+     */
+    private function fixEncoding($strPath)
+    {
+        $codepage = 'Windows-' . trim(strstr(setlocale(LC_CTYPE, 0), '.'), '.');
+        if (function_exists('iconv')) {
+            $strPath = iconv('UTF-8', $codepage . '//IGNORE', $strPath);
+        } elseif (function_exists('mb_convert_encoding')) {
+            $strPath = mb_convert_encoding($strPath, $codepage, 'UTF-8');
+        }
+        return $strPath;
+    }
+
 }
