@@ -222,14 +222,7 @@ abstract class AbstractLiquibaseTask extends Task
             );
         }
 
-        if ((null === $this->changeLogFile) or !file_exists($this->changeLogFile)) {
-            throw new BuildException(
-                sprintf(
-                    'Specify the name of the Changelog file. "%s" does not exist!',
-                    $this->changeLogFile
-                )
-            );
-        }
+        $this->checkChangeLogFile();
 
         if (null === $this->classpathref) {
             throw new BuildException('Please provide a classpath!');
@@ -304,6 +297,28 @@ abstract class AbstractLiquibaseTask extends Task
 
         return;
     }
+
+    protected function checkChangeLogFile()
+    {
+        if (null === $this->changeLogFile) {
+            throw new BuildException('Specify the name of the changelog file.');
+        }
+
+        foreach (explode(":", $this->classpathref) as $path) {
+            if (file_exists($path . DIRECTORY_SEPARATOR . $this->changeLogFile)) {
+                return;
+            }
+        }
+
+        if (!file_exists($this->changeLogFile)) {
+            throw new BuildException(
+                sprintf(
+                    'The changelog file "%s" does not exist!',
+                    $this->changeLogFile
+                )
+            );
+        }
+    }
 }
 
 /**
