@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 62aade46a5933fa29d676ffa8d92a943d1ec7838 $
+ *  $Id: 0de09dc2fc5e271ecbfbb358c65130cd4876301f $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -38,7 +38,7 @@ include_once 'phing/util/DirectoryScanner.php';
  * @author    Jon S. Stevens <jon@clearink.com> (Ant
  * @author    Stefan Bodewig <stefan.bodewig@epost.de> (Ant)
  * @author    Bruce Atherton <bruce@callenish.com> (Ant)
- * @version   $Id: 62aade46a5933fa29d676ffa8d92a943d1ec7838 $
+ * @version   $Id: 0de09dc2fc5e271ecbfbb358c65130cd4876301f $
  * @package   phing.tasks.system
  */
 abstract class MatchingTask extends Task implements SelectorContainer
@@ -389,6 +389,24 @@ abstract class MatchingTask extends Task implements SelectorContainer
         return $this->fileset->createDepend();
     }
 
+    /**
+     * add a readable selector entry on the selector list
+     * @return ReadableSelector
+     */
+    public function createReadable()
+    {
+        return $this->fileset->createReadable();
+    }
+
+    /**
+     * add a writable selector entry on the selector list
+     * @return WritableSelector
+     */
+    public function createWritable()
+    {
+        return $this->fileset->createWritable();
+    }
+
     /**
      * Accessor for the implict fileset.
      *
