@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: e24e1ffe735595a444812e2144455683b00fc371 $
+ *  $Id: 0df7e2e9aeb1d0ee94e2ead72891b5342ae13af8 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -44,6 +44,8 @@ include_once 'phing/types/selectors/OrSelector.php';
 include_once 'phing/types/selectors/PresentSelector.php';
 include_once 'phing/types/selectors/SizeSelector.php';
 include_once 'phing/types/selectors/TypeSelector.php';
+include_once 'phing/types/selectors/ReadableSelector.php';
+include_once 'phing/types/selectors/WritableSelector.php';
 
 include_once 'phing/util/DirectoryScanner.php';
 
@@ -62,7 +64,7 @@ include_once 'phing/util/DirectoryScanner.php';
  *
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @author    Hans Lellelid <hans@xmpl.org>
- * @version    $Id: e24e1ffe735595a444812e2144455683b00fc371 $
+ * @version    $Id: 0df7e2e9aeb1d0ee94e2ead72891b5342ae13af8 $
  * @see        ProjectComponent
  * @package    phing.types
  */
@@ -713,4 +715,26 @@ class AbstractFileSet extends DataType implements SelectorContainer
 
         return $o;
     }
+
+    /**
+     * add a readable selector entry on the selector list
+     */
+    public function createReadable()
+    {
+        $o = new ReadableSelector();
+        $this->appendSelector($o);
+
+        return $o;
+    }
+
+    /**
+     * add a writable selector entry on the selector list
+     */
+    public function createWritable()
+    {
+        $o = new WritableSelector();
+        $this->appendSelector($o);
+
+        return $o;
+    }
 }
