@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: b578f5cdbe1b9022fae4187fe18769f1558a8a4e $
+ *  $Id: 3f90e744c1e410a8b6fb2cd3868b26b3c46bac9f $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -41,7 +41,7 @@ include_once 'phing/system/io/PhingFile.php';
  * (or a mixture of files="" and listfile="" can be used)
  *
  * @author Hans Lellelid <hans@xmpl.org>
- * @version $Id: b578f5cdbe1b9022fae4187fe18769f1558a8a4e $
+ * @version $Id: 3f90e744c1e410a8b6fb2cd3868b26b3c46bac9f $
  * @package phing.types
  */
 class FileList extends DataType
@@ -245,7 +245,7 @@ class FileList extends DataType
             if ($listReader) {
                 $listReader->close();
             }
-            throw new BuildException("An error occured while reading from list file " . $this->listfile->__toString(
+            throw new BuildException("An error occurred while reading from list file " . $this->listfile->__toString(
                 ) . ": " . $e->getMessage());
         }
 
