@@ -1,7 +1,7 @@
 <?php
 
 /*
- * $Id: 2c553223ab4202fbe25c88ced7279bd79abe69c1 $
+ * $Id: f3f01f53eeee0ccfc7066a5335b69e697244375d $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -311,4 +311,25 @@ abstract class BaseSelectorContainer extends BaseSelector implements SelectorCon
         return $o;
     }
 
+    /**
+     * add a readable selector entry on the selector list
+     */
+    public function createReadable()
+    {
+        $o = new ReadableSelector();
+        $this->appendSelector($o);
+
+        return $o;
+    }
+
+    /**
+     * add a writable selector entry on the selector list
+     */
+    public function createWritable()
+    {
+        $o = new WritableSelector();
+        $this->appendSelector($o);
+
+        return $o;
+    }
 }
